@@ -1,6 +1,9 @@
 """pospell is a spellcheckers for po files containing reStructuedText.
 """
+from collections import defaultdict
 import io
+from string import digits
+from unicodedata import category
 import logging
 import subprocess
 import sys
@@ -19,10 +22,11 @@ from docutils.utils import new_document
 
 import regex
 
-__version__ = "1.0.4"
+__version__ = "1.0.7"
 
 DEFAULT_DROP_CAPITALIZED = {"fr": True, "fr_FR": True}
 
+
 try:
     HUNSPELL_VERSION = subprocess.check_output(
         ["hunspell", "--version"], universal_newlines=True
@@ -65,13 +69,11 @@ class NodeToTextVisitor(docutils.nodes.NodeVisitor):
         super().dispatch_departure(node)
 
     def unknown_visit(self, node):
-        """Mandatory implementation to visit unknwon nodes.
-        """
+        """Mandatory implementation to visit unknwon nodes."""
         # print(" " * self.depth * 4, node.__class__.__name__, ":", node)
 
     def unknown_departure(self, node):
-        """To help debugging tree.
-        """
+        """To help debugging tree."""
         # print(node, repr(node), node.__class__.__name__)
 
     def visit_emphasis(self, node):
@@ -108,9 +110,27 @@ def strip_rst(line):
         line = line[:-2]
     parser = docutils.parsers.rst.Parser()
     components = (docutils.parsers.rst.Parser,)
-    settings = docutils.frontend.OptionParser(
-        components=components
-    ).get_default_values()
+    settings = docutils.frontend.Values(
+        {
+            "report_level": 2,
+            "halt_level": 4,
+            "exit_status_level": 5,
+            "debug": None,
+            "warning_stream": None,
+            "error_encoding": "utf-8",
+            "error_encoding_error_handler": "backslashreplace",
+            "language_code": "en",
+            "id_prefix": "",
+            "auto_id_prefix": "id",
+            "pep_references": None,
+            "pep_base_url": "http://www.python.org/dev/peps/",
+            "pep_file_url_template": "pep-%04d",
+            "rfc_references": None,
+            "rfc_base_url": "http://tools.ietf.org/html/",
+            "tab_width": 8,
+            "trim_footnote_reference_space": None,
+        }
+    )
     stderr_stringio = io.StringIO()
     with redirect_stderr(stderr_stringio):
         document = new_document("<rst-doc>", settings=settings)
@@ -123,25 +143,16 @@ def strip_rst(line):
     return str(visitor)
 
 
-def clear(po_path, line, drop_capitalized=False):
-    """Clear various other syntaxes we may encounter in a line.
-    """
+def clear(line, drop_capitalized=False, po_path=""):
+    """Clear various other syntaxes we may encounter in a line."""
     # Normalize spaces
-    line = regex.sub(r"\s+", " ", line)
+    line = regex.sub(r"\s+", " ", line).replace("\xad", "")
+
     to_drop = {
         r'<a href="[^"]*?">',
-        # Strip accronyms
-        r"\b[\w-]*\p{Uppercase}{2,}[0-9.\w-]*\b",
-        r"---?",  # -- and --- separators to be ignored
-        r" - ",  # Drop lone dashes (sometimes used in place of -- or ---)
-        r"-\\ ",  # Ignore "MINUS BACKSLASH SPACE" typically used in
-        # formulas, like '-\ *π*' but *π* gets removed too
         r"{[a-z_]*?}",  # Sphinx variable
-        r"'?-?\b([0-9]+\.)*[0-9]+\.[0-9abcrx]+\b'?",  # Versions
-        r"[0-9]+h",  # Hours
         r"%\([a-z_]+?\)[diouxXeEfFgGcrsa%]",  # Sphinx variable
         r"« . »",  # Single letter examples (typically in Unicode documentation)
-        "\xad",  # soft hyphen
     }
     if drop_capitalized:
         to_drop.add(
@@ -175,14 +186,13 @@ def po_to_text(po_path, drop_capitalized=False):
         while lines < entry.linenum:
             buffer.append("")
             lines += 1
-        buffer.append(clear(po_path, strip_rst(entry.msgstr), drop_capitalized))
+        buffer.append(clear(strip_rst(entry.msgstr), drop_capitalized, po_path=po_path))
         lines += 1
     return "\n".join(buffer)
 
 
 def parse_args():
-    """Parse command line arguments.
-    """
+    """Parse command line arguments."""
     import argparse
 
     parser = argparse.ArgumentParser(
@@ -247,8 +257,27 @@ def parse_args():
     return args
 
 
+def look_like_a_word(word):
+    """Used to filter out non-words like `---` or `-0700` so they don't
+    get reported. They typically are not errors.
+    """
+    if not word:
+        return False
+    if any(digit in word for digit in digits):
+        return False
+    if len([c for c in word if category(c) == "Lu"]) > 1:
+        return False  # Probably an accronym, or a name like CPython, macOS, SQLite, ...
+    if "-" in word:
+        return False
+    return True
+
+
 def spell_check(
-    po_files, personal_dict, language, drop_capitalized=False, debug_only=False
+    po_files,
+    personal_dict=None,
+    language="en_US",
+    drop_capitalized=False,
+    debug_only=False,
 ):
     """Check for spelling mistakes in the files po_files (po format,
     containing restructuredtext), for the given language.
@@ -256,40 +285,40 @@ def spell_check(
 
     Debug only will show what's passed to Hunspell instead of passing it.
     """
-    errors = 0
+    errors = []
     personal_dict_arg = ["-p", personal_dict] if personal_dict else []
-    with tempfile.TemporaryDirectory() as tmpdirname:
-        tmpdir = Path(tmpdirname)
-        for po_file in po_files:
-            if debug_only:
-                print(po_to_text(str(po_file), drop_capitalized))
-                continue
-            (tmpdir / po_file.name).write_text(
-                po_to_text(str(po_file), drop_capitalized)
-            )
-            try:
-                output = subprocess.check_output(
-                    ["hunspell", "-d", language]
-                    + personal_dict_arg
-                    + ["-u3", str(tmpdir / po_file.name)],
-                    universal_newlines=True,
-                )
-            except subprocess.CalledProcessError:
-                return -1
-            for line in output.split("\n"):
-                match = regex.match(
-                    r"(?P<path>.*):(?P<line>[0-9]+): Locate: (?P<error>.*) \| Try: .*$",
-                    line,
-                )
-                if match:
-                    errors += 1
-                    print(po_file, match.group("line"), match.group("error"), sep=":")
-    return errors
+    texts_for_hunspell = {}
+    for po_file in po_files:
+        if debug_only:
+            print(po_to_text(str(po_file), drop_capitalized))
+            continue
+        texts_for_hunspell[po_file] = po_to_text(str(po_file), drop_capitalized)
+    try:
+        output = subprocess.run(
+            ["hunspell", "-d", language, "-l"] + personal_dict_arg,
+            universal_newlines=True,
+            input="\n".join(texts_for_hunspell.values()),
+            stdout=subprocess.PIPE,
+        )
+    except subprocess.CalledProcessError:
+        return -1
+    if not output.stdout:
+        return 0
+    for misspelled_word in {
+        word for word in output.stdout.split("\n") if look_like_a_word(word)
+    }:
+        for po_file, text_for_hunspell in texts_for_hunspell.items():
+            for line_number, line in enumerate(text_for_hunspell.split("\n"), start=1):
+                if misspelled_word in line:
+                    errors.append((po_file, line_number, misspelled_word))
+    errors.sort()
+    for error in errors:
+        print(":".join(str(token) for token in error))
+    return len(errors)
 
 
 def gracefull_handling_of_missing_dicts(language):
-    """Check if hunspell dictionary for given language is installed.
-    """
+    """Check if hunspell dictionary for given language is installed."""
     hunspell_dash_d = subprocess.check_output(
         ["hunspell", "-D"], universal_newlines=True, stderr=subprocess.STDOUT
     )
@@ -323,8 +352,7 @@ https://github.com/JulienPalard/pospell/) so I can enhance this error message.
 
 
 def main():
-    """Module entry point.
-    """
+    """Module entry point."""
     args = parse_args()
     logging.basicConfig(level=50 - 10 * args.verbose)
     default_drop_capitalized = DEFAULT_DROP_CAPITALIZED.get(args.language, False)
